/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM diIIconFinder.idl
 */

#ifndef __gen_diIIconFinder_h__
#define __gen_diIIconFinder_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    diIIconFinder */
#define DIIICONFINDER_IID_STR "59ee6c60-8c13-490b-acac-4d1dfca2bd1f"

#define DIIICONFINDER_IID \
  {0x59ee6c60, 0x8c13, 0x490b, \
    { 0xac, 0xac, 0x4d, 0x1d, 0xfc, 0xa2, 0xbd, 0x1f }}

/**
 *
 */
class NS_NO_VTABLE diIIconFinder : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(DIIICONFINDER_IID)

  /* wstring iconForURL (in wstring aUrl); */
  NS_IMETHOD IconForURL(const PRUnichar *aUrl, PRUnichar **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_DIIICONFINDER \
  NS_IMETHOD IconForURL(const PRUnichar *aUrl, PRUnichar **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_DIIICONFINDER(_to) \
  NS_IMETHOD IconForURL(const PRUnichar *aUrl, PRUnichar **_retval) { return _to IconForURL(aUrl, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_DIIICONFINDER(_to) \
  NS_IMETHOD IconForURL(const PRUnichar *aUrl, PRUnichar **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IconForURL(aUrl, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class diIconFinder : public diIIconFinder
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_DIIICONFINDER

  diIconFinder();

private:
  ~diIconFinder();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(diIconFinder, diIIconFinder)

diIconFinder::diIconFinder()
{
  /* member initializers and constructor code */
}

diIconFinder::~diIconFinder()
{
  /* destructor code */
}

/* wstring iconForURL (in wstring aUrl); */
NS_IMETHODIMP diIconFinder::IconForURL(const PRUnichar *aUrl, PRUnichar **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_diIIconFinder_h__ */
