/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIHTMLTemplateEditor.idl
 */

#ifndef __gen_nsIHTMLTemplateEditor_h__
#define __gen_nsIHTMLTemplateEditor_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_domstubs_h__
#include "domstubs.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIHTMLTemplateEditor */
#define NS_IHTMLTEMPLATEEDITOR_IID_STR "d650f925-27ea-4c06-b377-c51d641f3446"

#define NS_IHTMLTEMPLATEEDITOR_IID \
  {0xd650f925, 0x27ea, 0x4c06, \
    { 0xb3, 0x77, 0xc5, 0x1d, 0x64, 0x1f, 0x34, 0x46 }}

class NS_NO_VTABLE nsIHTMLTemplateEditor : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IHTMLTEMPLATEEDITOR_IID)

  /**
   * true if the selection container is absolutely positioned
   */
  /* attribute boolean isDocumentBasedOnTemplate; */
  NS_IMETHOD GetIsDocumentBasedOnTemplate(PRBool *aIsDocumentBasedOnTemplate) = 0;
  NS_IMETHOD SetIsDocumentBasedOnTemplate(PRBool aIsDocumentBasedOnTemplate) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIHTMLTEMPLATEEDITOR \
  NS_IMETHOD GetIsDocumentBasedOnTemplate(PRBool *aIsDocumentBasedOnTemplate); \
  NS_IMETHOD SetIsDocumentBasedOnTemplate(PRBool aIsDocumentBasedOnTemplate); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIHTMLTEMPLATEEDITOR(_to) \
  NS_IMETHOD GetIsDocumentBasedOnTemplate(PRBool *aIsDocumentBasedOnTemplate) { return _to GetIsDocumentBasedOnTemplate(aIsDocumentBasedOnTemplate); } \
  NS_IMETHOD SetIsDocumentBasedOnTemplate(PRBool aIsDocumentBasedOnTemplate) { return _to SetIsDocumentBasedOnTemplate(aIsDocumentBasedOnTemplate); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIHTMLTEMPLATEEDITOR(_to) \
  NS_IMETHOD GetIsDocumentBasedOnTemplate(PRBool *aIsDocumentBasedOnTemplate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsDocumentBasedOnTemplate(aIsDocumentBasedOnTemplate); } \
  NS_IMETHOD SetIsDocumentBasedOnTemplate(PRBool aIsDocumentBasedOnTemplate) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIsDocumentBasedOnTemplate(aIsDocumentBasedOnTemplate); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsHTMLTemplateEditor : public nsIHTMLTemplateEditor
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIHTMLTEMPLATEEDITOR

  nsHTMLTemplateEditor();

private:
  ~nsHTMLTemplateEditor();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsHTMLTemplateEditor, nsIHTMLTemplateEditor)

nsHTMLTemplateEditor::nsHTMLTemplateEditor()
{
  /* member initializers and constructor code */
}

nsHTMLTemplateEditor::~nsHTMLTemplateEditor()
{
  /* destructor code */
}

/* attribute boolean isDocumentBasedOnTemplate; */
NS_IMETHODIMP nsHTMLTemplateEditor::GetIsDocumentBasedOnTemplate(PRBool *aIsDocumentBasedOnTemplate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsHTMLTemplateEditor::SetIsDocumentBasedOnTemplate(PRBool aIsDocumentBasedOnTemplate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIHTMLTemplateEditor_h__ */
