/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIRDFDirectoryDataSource.idl
 */

#ifndef __gen_nsIRDFDirectoryDataSource_h__
#define __gen_nsIRDFDirectoryDataSource_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIRDFResource; /* forward declaration */

class nsISimpleEnumerator; /* forward declaration */


/* starting interface:    nsIRDFDirectoryDataSource */
#define NS_IRDFDIRECTORYDATASOURCE_IID_STR "d3199c29-5583-46b3-bfa4-3de1caf59884"

#define NS_IRDFDIRECTORYDATASOURCE_IID \
  {0xd3199c29, 0x5583, 0x46b3, \
    { 0xbf, 0xa4, 0x3d, 0xe1, 0xca, 0xf5, 0x98, 0x84 }}

class NS_NO_VTABLE nsIRDFDirectoryDataSource : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IRDFDIRECTORYDATASOURCE_IID)

  /* attribute boolean showHidden; */
  NS_IMETHOD GetShowHidden(PRBool *aShowHidden) = 0;
  NS_IMETHOD SetShowHidden(PRBool aShowHidden) = 0;

  /* nsIRDFResource getParentDirectory (in nsIRDFResource aSource); */
  NS_IMETHOD GetParentDirectory(nsIRDFResource *aSource, nsIRDFResource **_retval) = 0;

  /* nsISimpleEnumerator getParentDirectories (in nsIRDFResource aSource); */
  NS_IMETHOD GetParentDirectories(nsIRDFResource *aSource, nsISimpleEnumerator **_retval) = 0;

  /* nsIRDFResource getHomeDirectory (); */
  NS_IMETHOD GetHomeDirectory(nsIRDFResource **_retval) = 0;

  /* void createNewDirectory (in nsIRDFResource aSource, in AString aNewDirName); */
  NS_IMETHOD CreateNewDirectory(nsIRDFResource *aSource, const nsAString & aNewDirName) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIRDFDIRECTORYDATASOURCE \
  NS_IMETHOD GetShowHidden(PRBool *aShowHidden); \
  NS_IMETHOD SetShowHidden(PRBool aShowHidden); \
  NS_IMETHOD GetParentDirectory(nsIRDFResource *aSource, nsIRDFResource **_retval); \
  NS_IMETHOD GetParentDirectories(nsIRDFResource *aSource, nsISimpleEnumerator **_retval); \
  NS_IMETHOD GetHomeDirectory(nsIRDFResource **_retval); \
  NS_IMETHOD CreateNewDirectory(nsIRDFResource *aSource, const nsAString & aNewDirName); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIRDFDIRECTORYDATASOURCE(_to) \
  NS_IMETHOD GetShowHidden(PRBool *aShowHidden) { return _to GetShowHidden(aShowHidden); } \
  NS_IMETHOD SetShowHidden(PRBool aShowHidden) { return _to SetShowHidden(aShowHidden); } \
  NS_IMETHOD GetParentDirectory(nsIRDFResource *aSource, nsIRDFResource **_retval) { return _to GetParentDirectory(aSource, _retval); } \
  NS_IMETHOD GetParentDirectories(nsIRDFResource *aSource, nsISimpleEnumerator **_retval) { return _to GetParentDirectories(aSource, _retval); } \
  NS_IMETHOD GetHomeDirectory(nsIRDFResource **_retval) { return _to GetHomeDirectory(_retval); } \
  NS_IMETHOD CreateNewDirectory(nsIRDFResource *aSource, const nsAString & aNewDirName) { return _to CreateNewDirectory(aSource, aNewDirName); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIRDFDIRECTORYDATASOURCE(_to) \
  NS_IMETHOD GetShowHidden(PRBool *aShowHidden) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetShowHidden(aShowHidden); } \
  NS_IMETHOD SetShowHidden(PRBool aShowHidden) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetShowHidden(aShowHidden); } \
  NS_IMETHOD GetParentDirectory(nsIRDFResource *aSource, nsIRDFResource **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetParentDirectory(aSource, _retval); } \
  NS_IMETHOD GetParentDirectories(nsIRDFResource *aSource, nsISimpleEnumerator **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetParentDirectories(aSource, _retval); } \
  NS_IMETHOD GetHomeDirectory(nsIRDFResource **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHomeDirectory(_retval); } \
  NS_IMETHOD CreateNewDirectory(nsIRDFResource *aSource, const nsAString & aNewDirName) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateNewDirectory(aSource, aNewDirName); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsRDFDirectoryDataSource : public nsIRDFDirectoryDataSource
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIRDFDIRECTORYDATASOURCE

  nsRDFDirectoryDataSource();

private:
  ~nsRDFDirectoryDataSource();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsRDFDirectoryDataSource, nsIRDFDirectoryDataSource)

nsRDFDirectoryDataSource::nsRDFDirectoryDataSource()
{
  /* member initializers and constructor code */
}

nsRDFDirectoryDataSource::~nsRDFDirectoryDataSource()
{
  /* destructor code */
}

/* attribute boolean showHidden; */
NS_IMETHODIMP nsRDFDirectoryDataSource::GetShowHidden(PRBool *aShowHidden)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsRDFDirectoryDataSource::SetShowHidden(PRBool aShowHidden)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIRDFResource getParentDirectory (in nsIRDFResource aSource); */
NS_IMETHODIMP nsRDFDirectoryDataSource::GetParentDirectory(nsIRDFResource *aSource, nsIRDFResource **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsISimpleEnumerator getParentDirectories (in nsIRDFResource aSource); */
NS_IMETHODIMP nsRDFDirectoryDataSource::GetParentDirectories(nsIRDFResource *aSource, nsISimpleEnumerator **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIRDFResource getHomeDirectory (); */
NS_IMETHODIMP nsRDFDirectoryDataSource::GetHomeDirectory(nsIRDFResource **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void createNewDirectory (in nsIRDFResource aSource, in AString aNewDirName); */
NS_IMETHODIMP nsRDFDirectoryDataSource::CreateNewDirectory(nsIRDFResource *aSource, const nsAString & aNewDirName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIRDFDirectoryDataSource_h__ */
