/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIDOMNSCSSSelectorQuery.idl
 */

#ifndef __gen_nsIDOMNSCSSSelectorQuery_h__
#define __gen_nsIDOMNSCSSSelectorQuery_h__


#ifndef __gen_domstubs_h__
#include "domstubs.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDOMNSCSSSelectorQuery */
#define NS_IDOMNSCSSSELECTORQUERY_IID_STR "bee76522-0f18-4954-b0aa-d5760dfbbe1a"

#define NS_IDOMNSCSSSELECTORQUERY_IID \
  {0xbee76522, 0x0f18, 0x4954, \
    { 0xb0, 0xaa, 0xd5, 0x76, 0x0d, 0xfb, 0xbe, 0x1a }}

class NS_NO_VTABLE nsIDOMNSCSSSelectorQuery : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IDOMNSCSSSELECTORQUERY_IID)

  enum { SHOW_ALL = 4294967295U };

  enum { SHOW_TYPE_SELECTOR = 1U };

  enum { SHOW_CLASS_SELECTOR = 2U };

  enum { SHOW_ID_SELECTOR = 4U };

  /* nsIDOMDOMStringList getSelectorList (in unsigned long selectorFilter); */
  NS_IMETHOD GetSelectorList(PRUint32 selectorFilter, nsIDOMDOMStringList **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMNSCSSSELECTORQUERY \
  NS_IMETHOD GetSelectorList(PRUint32 selectorFilter, nsIDOMDOMStringList **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMNSCSSSELECTORQUERY(_to) \
  NS_IMETHOD GetSelectorList(PRUint32 selectorFilter, nsIDOMDOMStringList **_retval) { return _to GetSelectorList(selectorFilter, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMNSCSSSELECTORQUERY(_to) \
  NS_IMETHOD GetSelectorList(PRUint32 selectorFilter, nsIDOMDOMStringList **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSelectorList(selectorFilter, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMNSCSSSelectorQuery : public nsIDOMNSCSSSelectorQuery
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMNSCSSSELECTORQUERY

  nsDOMNSCSSSelectorQuery();

private:
  ~nsDOMNSCSSSelectorQuery();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMNSCSSSelectorQuery, nsIDOMNSCSSSelectorQuery)

nsDOMNSCSSSelectorQuery::nsDOMNSCSSSelectorQuery()
{
  /* member initializers and constructor code */
}

nsDOMNSCSSSelectorQuery::~nsDOMNSCSSSelectorQuery()
{
  /* destructor code */
}

/* nsIDOMDOMStringList getSelectorList (in unsigned long selectorFilter); */
NS_IMETHODIMP nsDOMNSCSSSelectorQuery::GetSelectorList(PRUint32 selectorFilter, nsIDOMDOMStringList **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMNSCSSSelectorQuery_h__ */
