/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or 
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsIChannel.idl"
interface nsIRequestObserver;

// this interface provides a way for the FTP connection to 
// synchronize with the owning channel.

[scriptable, uuid(deb19f2a-ad32-47c4-85f4-b799fd7f1e51)]
interface nsIFTPChannel : nsIChannel
{
  /**
   * This method prepares the channel for the deletion of a file. The
   * deletion itself will be performed when the channel is opened,
   * synchronously or not.
   */
  void deleteFile();

  /**
   * This method prepares the channel for the creation of a new directory.
   * The creation itself will be performed when the channel is opened,
   * synchronously or not.
   */
  void createDirectory();

  /**
   * This method prepares the channel for the removal of a directory.
   * The removal itself will be performed when the channel is opened,
   * synchronously or not.
   */
  void removeDirectory();

  /*
   * This method prepares the channel for renaming. The renaming itself
   * will be will be performed when the channel is opened,
   * synchronously or not.
   */
  void renameTo(in AString aNewName);
};

[scriptable, uuid(455d4234-0330-43d2-bbfb-99afbecbfeb0)]
interface nsIFTPEventSink : nsISupports
{
    void OnFTPControlLog(in boolean server, in string msg);
};

