/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIFTPChannel.idl
 */

#ifndef __gen_nsIFTPChannel_h__
#define __gen_nsIFTPChannel_h__


#ifndef __gen_nsIChannel_h__
#include "nsIChannel.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIRequestObserver; /* forward declaration */


/* starting interface:    nsIFTPChannel */
#define NS_IFTPCHANNEL_IID_STR "deb19f2a-ad32-47c4-85f4-b799fd7f1e51"

#define NS_IFTPCHANNEL_IID \
  {0xdeb19f2a, 0xad32, 0x47c4, \
    { 0x85, 0xf4, 0xb7, 0x99, 0xfd, 0x7f, 0x1e, 0x51 }}

class NS_NO_VTABLE nsIFTPChannel : public nsIChannel {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IFTPCHANNEL_IID)

  /**
   * This method prepares the channel for the deletion of a file. The
   * deletion itself will be performed when the channel is opened,
   * synchronously or not.
   */
  /* void deleteFile (); */
  NS_IMETHOD DeleteFile(void) = 0;

  /**
   * This method prepares the channel for the creation of a new directory.
   * The creation itself will be performed when the channel is opened,
   * synchronously or not.
   */
  /* void createDirectory (); */
  NS_IMETHOD CreateDirectory(void) = 0;

  /**
   * This method prepares the channel for the removal of a directory.
   * The removal itself will be performed when the channel is opened,
   * synchronously or not.
   */
  /* void removeDirectory (); */
  NS_IMETHOD RemoveDirectory(void) = 0;

  /* void renameTo (in AString aNewName); */
  NS_IMETHOD RenameTo(const nsAString & aNewName) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIFTPCHANNEL \
  NS_IMETHOD DeleteFile(void); \
  NS_IMETHOD CreateDirectory(void); \
  NS_IMETHOD RemoveDirectory(void); \
  NS_IMETHOD RenameTo(const nsAString & aNewName); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIFTPCHANNEL(_to) \
  NS_IMETHOD DeleteFile(void) { return _to DeleteFile(); } \
  NS_IMETHOD CreateDirectory(void) { return _to CreateDirectory(); } \
  NS_IMETHOD RemoveDirectory(void) { return _to RemoveDirectory(); } \
  NS_IMETHOD RenameTo(const nsAString & aNewName) { return _to RenameTo(aNewName); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIFTPCHANNEL(_to) \
  NS_IMETHOD DeleteFile(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteFile(); } \
  NS_IMETHOD CreateDirectory(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateDirectory(); } \
  NS_IMETHOD RemoveDirectory(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveDirectory(); } \
  NS_IMETHOD RenameTo(const nsAString & aNewName) { return !_to ? NS_ERROR_NULL_POINTER : _to->RenameTo(aNewName); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsFTPChannel : public nsIFTPChannel
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIFTPCHANNEL

  nsFTPChannel();

private:
  ~nsFTPChannel();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsFTPChannel, nsIFTPChannel)

nsFTPChannel::nsFTPChannel()
{
  /* member initializers and constructor code */
}

nsFTPChannel::~nsFTPChannel()
{
  /* destructor code */
}

/* void deleteFile (); */
NS_IMETHODIMP nsFTPChannel::DeleteFile()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void createDirectory (); */
NS_IMETHODIMP nsFTPChannel::CreateDirectory()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeDirectory (); */
NS_IMETHODIMP nsFTPChannel::RemoveDirectory()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void renameTo (in AString aNewName); */
NS_IMETHODIMP nsFTPChannel::RenameTo(const nsAString & aNewName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIFTPEventSink */
#define NS_IFTPEVENTSINK_IID_STR "455d4234-0330-43d2-bbfb-99afbecbfeb0"

#define NS_IFTPEVENTSINK_IID \
  {0x455d4234, 0x0330, 0x43d2, \
    { 0xbb, 0xfb, 0x99, 0xaf, 0xbe, 0xcb, 0xfe, 0xb0 }}

class NS_NO_VTABLE nsIFTPEventSink : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IFTPEVENTSINK_IID)

  /* void OnFTPControlLog (in boolean server, in string msg); */
  NS_IMETHOD OnFTPControlLog(PRBool server, const char *msg) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIFTPEVENTSINK \
  NS_IMETHOD OnFTPControlLog(PRBool server, const char *msg); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIFTPEVENTSINK(_to) \
  NS_IMETHOD OnFTPControlLog(PRBool server, const char *msg) { return _to OnFTPControlLog(server, msg); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIFTPEVENTSINK(_to) \
  NS_IMETHOD OnFTPControlLog(PRBool server, const char *msg) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnFTPControlLog(server, msg); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsFTPEventSink : public nsIFTPEventSink
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIFTPEVENTSINK

  nsFTPEventSink();

private:
  ~nsFTPEventSink();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsFTPEventSink, nsIFTPEventSink)

nsFTPEventSink::nsFTPEventSink()
{
  /* member initializers and constructor code */
}

nsFTPEventSink::~nsFTPEventSink()
{
  /* destructor code */
}

/* void OnFTPControlLog (in boolean server, in string msg); */
NS_IMETHODIMP nsFTPEventSink::OnFTPControlLog(PRBool server, const char *msg)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIFTPChannel_h__ */
